#ifndef NT2_INCLUDE_FUNCTIONS_ELLIPKE_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_ELLIPKE_HPP_INCLUDED

#include <nt2/elliptic/include/functions/ellipke.hpp>

#endif
